summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorelliott_c <ocielliottc@users.noreply.github.com>2004-12-02 19:39:03 +0000
committerelliott_c <ocielliottc@users.noreply.github.com>2004-12-02 19:39:03 +0000
commit0f4945223ac0d2f36e2f6d450349a4c77e9cd7b4 (patch)
treef2971d68a4928d842f536a2a7b61f422f15f482a
parent3aa9bf7e699f0e20307758589c54984646493aa2 (diff)
downloadATCD-0f4945223ac0d2f36e2f6d450349a4c77e9cd7b4.tar.gz
ChangeLogTag: Thu Dec 2 13:38:33 2004 Chad Elliott <elliott_c@ociweb.com>
-rw-r--r--ChangeLog72
-rw-r--r--apps/soreduce/Library.cpp212
-rw-r--r--apps/soreduce/Library.h57
-rw-r--r--apps/soreduce/README24
4 files changed, 171 insertions, 194 deletions
diff --git a/ChangeLog b/ChangeLog
index d51c60b7c44..31455d33259 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,31 +1,39 @@
+Thu Dec 2 13:38:33 2004 Chad Elliott <elliott_c@ociweb.com>
+
+ * apps/soreduce/Library.h:
+ * apps/soreduce/Library.cpp:
+ * apps/soreduce/README:
+
+ Modified soreduce to output mpc files instead of makefiles.
+
Thu Dec 2 11:09:07 2004 J.T. Conklin <jtc@acorntoolworks.com>
- * apps/gperf/tests/Makefile.am:
+ * apps/gperf/tests/Makefile.am:
- Revert my previous change. Fixed orignal problem by putting the
- stamp file in the same directory as the output file. Thanks to
- Chad Elliott for letting me know that the gperf options for the
- two invocations of gperf on idl.gperf were different.
+ Revert my previous change. Fixed orignal problem by putting the
+ stamp file in the same directory as the output file. Thanks to
+ Chad Elliott for letting me know that the gperf options for the
+ two invocations of gperf on idl.gperf were different.
Thu Dec 2 16:42:12 UTC 2004 Martin Corino <mcorino@remedy.nl>
* include/makeinclude/platform_vxworks5.5.x.GNU:
- Added explicit 'signed-char' flags for ppc and arm builds.
+ Added explicit 'signed-char' flags for ppc and arm builds.
Thu Dec 2 11:08:29 2004 Steve Huston <shuston@riverace.com>
- * examples/APG/Threads/Guards.cpp: Fixed "unused parameter" warning.
+ * examples/APG/Threads/Guards.cpp: Fixed "unused parameter" warning.
Thu Dec 2 15:06:12 UTC 2004 Martin Corino <mcorino@remedy.nl>
* ace/Timeprobe_T.cpp:
- Fixed another compile problem (missing include for ACE_OS::memcpy).
+ Fixed another compile problem (missing include for ACE_OS::memcpy).
Thu Dec 2 14:26:12 UTC 2004 Martin Corino <mcorino@remedy.nl>
* ace/Timeprobe_T.cpp:
- Fixed error in ACE_Timeprobe_Ex<>::print_absolute_times() where ACE_hrtime_t
- was incorrectly assumed to be a structure/class (it's an integer type).
+ Fixed error in ACE_Timeprobe_Ex<>::print_absolute_times() where ACE_hrtime_t
+ was incorrectly assumed to be a structure/class (it's an integer type).
Thu Dec 2 09:45:12 UTC 2004 Johnny Willemsen <jwillemsen@remedy.nl>
@@ -49,11 +57,11 @@ Thu Dec 2 08:32:12 UTC 2004 Martin Corino <mcorino@remedy.nl>
Wed Dec 1 15:01:39 2004 Steve Huston <shuston@riverace.com>
- * examples/APG/Threads/Guards.cpp:
- * examples/APG/Threads/Message_Blocks.cpp: Enabled the code here that
- was previously blocked out. Fixed narrow/wide-char spec for a
- string to ACE_Log_Msg. Thanks to Johnny Willemsen for pointing
- out that none of this code was actually getting compiled.
+ * examples/APG/Threads/Guards.cpp:
+ * examples/APG/Threads/Message_Blocks.cpp: Enabled the code here that
+ was previously blocked out. Fixed narrow/wide-char spec for a
+ string to ACE_Log_Msg. Thanks to Johnny Willemsen for pointing
+ out that none of this code was actually getting compiled.
Wed Dec 1 08:49:12 UTC 2004 Martin Corino <mcorino@remedy.nl>
@@ -64,24 +72,24 @@ Tue Nov 30 16:38:08 2004 J.T. Conklin <jtc@acorntoolworks.com>
* apps/gperf/tests/Makefile.am:
- Changed to only generate idl.cpp from idl.gperf once. The
- attempt to generate it twice, the a second time in a different
- directory failed because the "stamp" file was the same.
+ Changed to only generate idl.cpp from idl.gperf once. The
+ attempt to generate it twice, the a second time in a different
+ directory failed because the "stamp" file was the same.
Tue Nov 30 17:32:29 2004 Steve Huston <shuston@riverace.com>
- * m4/ace.m4: Added two new options, --enable-pthreads and
- --enable-uithreads. These en/dis-able the use of Pthreads and
- UI Threads (aka Solaris threads), respectively. Some platforms
- (namely AIX) offer a hokey UI Threads that barely functions but
- can't be used for any real work. Efforts to detect this and
- automatically disable it have been unfruitful, so this option was
- added. Pthreads defaults to yes, UI threads defaults to, except on
- Solaris where it defaults to yes.
+ * m4/ace.m4: Added two new options, --enable-pthreads and
+ --enable-uithreads. These en/dis-able the use of Pthreads and
+ UI Threads (aka Solaris threads), respectively. Some platforms
+ (namely AIX) offer a hokey UI Threads that barely functions but
+ can't be used for any real work. Efforts to detect this and
+ automatically disable it have been unfruitful, so this option was
+ added. Pthreads defaults to yes, UI threads defaults to, except on
+ Solaris where it defaults to yes.
- * m4/threads.m4: Only do Pthreads/UIthreads checks if the corresponding
- implementation is enabled by the command line (or default) using
- the above new options.
+ * m4/threads.m4: Only do Pthreads/UIthreads checks if the corresponding
+ implementation is enabled by the command line (or default) using
+ the above new options.
Tue Nov 30 07:32:18 2004 Chad Elliott <elliott_c@ociweb.com>
@@ -731,9 +739,9 @@ Thu Nov 18 07:38:34 2004 Chad Elliott <elliott_c@ociweb.com>
* ace/Service_Config.cpp:
Distinguish between the existence of and the file permissions
- for the default service configurator file (svc.conf). Thanks to
- Dipa Suri <dipa.suri@lmco.com> and Adam Howell
- <adam.s.howell@lmco.com> for reporting this.
+ for the default service configurator file (svc.conf). Thanks to
+ Dipa Suri <dipa.suri@lmco.com> and Adam Howell
+ <adam.s.howell@lmco.com> for reporting this.
Thu Nov 18 07:10:26 2004 Chad Elliott <elliott_c@ociweb.com>
diff --git a/apps/soreduce/Library.cpp b/apps/soreduce/Library.cpp
index b56579092c4..2d3546467ef 100644
--- a/apps/soreduce/Library.cpp
+++ b/apps/soreduce/Library.cpp
@@ -6,7 +6,7 @@
// Author: Phil Mesnier
// This file contains the implementation of the classes responsible for
-// generating specialized makefiles for individual libraries, as well as
+// generating specialized mpc files for individual libraries, as well as
// outputting usage metrics for the various object modules contained in the
// library.
@@ -15,174 +15,147 @@
#include "ace/OS_NS_string.h"
#include "ace/OS_NS_unistd.h"
#include "ace/OS_NS_sys_stat.h"
+#include "ace/OS_NS_ctype.h"
#include "ace/Log_Msg.h"
#include "Library.h"
ACE_RCSID(src, Library, "$Id$")
-Makefile_Generator::Makefile_Generator (const ACE_CString& libname)
- : makefile_(),
+MPC_Generator::MPC_Generator (const ACE_CString& libname)
+ : mpcfile_(),
libname_(libname),
- makefilename_()
+ mpcfilename_()
{
- makefilename_ = "Makefile." + libname_ + "_subset";
+ mpcfilename_ = libname_ + "_subset.mpc";
}
-Makefile_Generator::~Makefile_Generator ()
+MPC_Generator::~MPC_Generator ()
{
}
void
-Makefile_Generator::write_file (const ACE_CString& file)
+MPC_Generator::write_file (const ACE_CString& file)
{
- makefile_ << " \\\n\t" << file << flush;
+ mpcfile_ << " " << file << ".cpp" << endl;
}
void
-Makefile_Generator::write_prolog (const ACE_CString& path)
+MPC_Generator::write_prolog (const ACE_CString& path)
{
- ACE_CString fname (path + "/" + makefilename_);
+ ACE_CString fname (path + "/" + mpcfilename_);
ACE_DEBUG ((LM_DEBUG, "writing file %s\n",fname.c_str()));
- makefile_.open(fname.c_str());
- if (!makefile_)
- ACE_DEBUG ((LM_DEBUG,"makefile open failed\n"));
-
- makefile_
- << "#--------------------------------------------------------------------"
- << endl;
- makefile_
- << "# Generated makefile for producing a subset of the "
- << libname_ << " library " << endl;
- makefile_
- << "#--------------------------------------------------------------------"
- << endl;
-
- makefile_ << "\nMAKEFILE = " << makefilename_ << endl;
- makefile_ << "LIB = lib" << libname_ << "_subset.a" << endl;
- makefile_ << "SHLIB = lib" << libname_ << "_subset.$(SOEXT)" << endl;
- makefile_ << "\nFILES =" << flush;
-}
+ mpcfile_.open(fname.c_str());
+ if (!mpcfile_)
+ ACE_DEBUG ((LM_DEBUG,"mpc file open failed\n"));
-void
-Makefile_Generator::write_epilog ()
-{
- makefile_ << "\n" << endl;
- this->write_libdeps();
- makefile_
- << "#--------------------------------------------------------" << endl;
- makefile_
- << "# Include macros and targets" << endl;
- makefile_
- << "#--------------------------------------------------------" << endl;
- makefile_
- << "include $(ACE_ROOT)/include/makeinclude/wrapper_macros.GNU" << endl;
-
- this->write_initial_rules();
-
- makefile_
- << "\nLSRC = $(addsuffix .cpp,$(FILES))\n" << endl;
-
- makefile_
- << "include $(ACE_ROOT)/include/makeinclude/macros.GNU" << endl;
- makefile_
- << "include $(ACE_ROOT)/include/makeinclude/rules.common.GNU" << endl;
- makefile_
- << "include $(ACE_ROOT)/include/makeinclude/rules.nested.GNU" << endl;
- makefile_
- << "include $(ACE_ROOT)/include/makeinclude/rules.lib.GNU" << endl;
- makefile_
- << "include $(ACE_ROOT)/include/makeinclude/rules.local.GNU" << endl;
-
- this->write_final_rules();
-
- makefile_ << "\n" << endl;
-
- makefile_
- << "#-----------------------------------------------------------" << endl;
- makefile_
- << "# Dependencies" << endl;
- makefile_
- << "#-----------------------------------------------------------" << endl;
- makefile_
- << "# DO NOT DELETE THIS LINE -- g++dep uses it." << endl;
- makefile_
- << "# DO NOT PUT ANYTHING AFTER THIS LINE, IT WILL GO AWAY." << endl;
- makefile_
- << "# IF YOU PUT ANYTHING HERE IT WILL GO AWAY" << endl;
-
- makefile_.close();
+ mpcfile_
+ << "// Generated mpc file for producing a subset of the "
+ << libname_ << " library " << endl << endl
+ << "project(" << libname_ << "_subset)";
+
+ this->write_baseprojects ();
+
+ mpcfile_
+ << " {" << endl
+ << " sharedname = " << libname_ << "_subset" << endl
+ << " pch_header = " << endl
+ << " pch_source = " << endl;
+
+ this->write_projectinfo ();
+
+ mpcfile_ << endl
+ << " Source_Files {" << endl;
}
void
-Makefile_Generator::write_libdeps()
+MPC_Generator::write_epilog ()
{
- // nothing to do
+ mpcfile_ << " }" << endl
+ << "}" << endl;
+ mpcfile_.close();
}
void
-Makefile_Generator::write_initial_rules()
+MPC_Generator::write_baseprojects()
{
- // nothing to do
+ mpcfile_ << ": acedefaults, aceversion, core";
}
void
-Makefile_Generator::write_final_rules()
+MPC_Generator::write_projectinfo()
{
- // nothing to do
+ mpcfile_ << " libout = $(ACE_ROOT)/lib" << endl
+ << " dynamicflags = ACE_BUILD_DLL ACE_OS_BUILD_DLL" << endl;
}
//-----------------------------------------------------------------------------
-Make_ACE_Dep_Lib::Make_ACE_Dep_Lib (const ACE_CString& libname)
- : Makefile_Generator(libname)
+MPC_ACE_Dep_Lib::MPC_ACE_Dep_Lib (const ACE_CString& libname)
+ : MPC_Generator(libname)
{}
void
-Make_ACE_Dep_Lib::write_libdeps()
+MPC_ACE_Dep_Lib::write_baseprojects()
{
- makefile_ << "ACE_SHLIBS = -lACE_subset" << endl;
+ mpcfile_ << ": acedefaults, aceversion";
}
-//-----------------------------------------------------------------------------
-Make_TAO_Lib::Make_TAO_Lib (const ACE_CString& libname)
- : Make_ACE_Dep_Lib(libname)
-{}
-
void
-Make_TAO_Lib::write_libdeps()
+MPC_ACE_Dep_Lib::write_projectinfo()
{
- makefile_ << "ifndef TAO_ROOT" << endl;
- makefile_ << "TAO_ROOT = $(ACE_ROOT)/TAO" << endl;
- makefile_ << "endif" << endl;
-
- makefile_ << "ACE_SHLIBS = -lACE_subset" << endl;
+ mpcfile_ << " libout = $(ACE_ROOT)/lib" << endl
+ << " libs += ACE_subset" << endl
+ << " after += ACE_subset" << endl;
}
+//-----------------------------------------------------------------------------
+MPC_TAO_Lib::MPC_TAO_Lib (const ACE_CString& libname)
+ : MPC_ACE_Dep_Lib(libname)
+{}
+
void
-Make_TAO_Lib::write_initial_rules()
+MPC_TAO_Lib::write_baseprojects()
{
- makefile_ << "include $(TAO_ROOT)/rules.tao.GNU" << endl;
+ MPC_ACE_Dep_Lib::write_baseprojects ();
+ mpcfile_ << ", taoversion, core, tao_output, taodefaults";
}
void
-Make_TAO_Lib::write_final_rules()
+MPC_TAO_Lib::write_projectinfo()
{
- makefile_ << "include $(TAO_ROOT)/taoconfig.mk" << endl;
+ MPC_ACE_Dep_Lib::write_projectinfo();
+ mpcfile_ << " dynamicflags = TAO_BUILD_DLL" << endl;
}
//-----------------------------------------------------------------------------
-Make_TAO_Dep_Lib::Make_TAO_Dep_Lib (const ACE_CString& libname)
- : Make_TAO_Lib(libname)
+MPC_TAO_Dep_Lib::MPC_TAO_Dep_Lib (const ACE_CString& libname)
+ : MPC_TAO_Lib(libname)
{}
void
-Make_TAO_Dep_Lib::write_libdeps()
+MPC_TAO_Dep_Lib::write_baseprojects()
{
- makefile_ << "ifndef TAO_ROOT" << endl;
- makefile_ << "TAO_ROOT = $(ACE_ROOT)/TAO" << endl;
- makefile_ << "endif" << endl;
+ MPC_TAO_Lib::write_baseprojects ();
+ mpcfile_ << ", taoidldefaults";
+}
- makefile_ << "ACE_SHLIBS = -lTAO_subset -lACE_subset" << endl;
+void
+MPC_TAO_Dep_Lib::write_projectinfo()
+{
+ // Try our best to generate the dynamicflags
+ ACE_CString dflags;
+ for(size_t i = 0; i < this->libname_.length (); ++i) {
+ dflags += static_cast<char>(ACE_OS::ace_toupper (this->libname_[i]));
+ }
+ dflags += "_BUILD_DLL";
+
+ MPC_ACE_Dep_Lib::write_projectinfo();
+ mpcfile_ << " dynamicflags = " << dflags.c_str () << endl
+ << " libs += TAO_subset" << endl
+ << " after += TAO_subset" << endl
+ << " includes += $(TAO_ROOT)/orbsvcs" << endl
+ << " idlflags += -I$(TAO_ROOT)/orbsvcs" << endl;
+
}
//-----------------------------------------------------------------------------
@@ -195,21 +168,21 @@ Library::Library (const char *name)
num_extrefs_(0),
modules_(0),
exported_(0),
- makefile_(0)
+ mpcfile_(0)
{
if (name_ == "ACE")
- makefile_ = new Makefile_Generator(name_);
+ mpcfile_ = new MPC_Generator(name_);
else if (name_.find ("ACE_") == 0)
- makefile_ = new Make_ACE_Dep_Lib (name_);
+ mpcfile_ = new MPC_ACE_Dep_Lib (name_);
else if (name_ == "TAO")
- makefile_ = new Make_TAO_Lib (name_);
+ mpcfile_ = new MPC_TAO_Lib (name_);
else
- makefile_ = new Make_TAO_Dep_Lib (name_);
+ mpcfile_ = new MPC_TAO_Dep_Lib (name_);
}
Library::~Library ()
{
- delete makefile_;
+ delete mpcfile_;
int i;
for (i = 0; i < num_modules_; delete modules_[i++]);
delete [] modules_;
@@ -330,14 +303,15 @@ Library::write_export_list (int show_ref_counts)
if (show_ref_counts) {
ACE_DEBUG ((LM_DEBUG, "Making directory %s\n",rcpath.c_str()));
- if (ACE_OS::mkdir(ACE_TEXT_CHAR_TO_TCHAR (rcpath.c_str())) == -1)
+ if (ACE_OS::mkdir(ACE_TEXT_CHAR_TO_TCHAR (rcpath.c_str())) == -1 &&
+ errno != EEXIST)
ACE_ERROR ((LM_ERROR, "%p\n", "mkdir"));
}
ACE_DEBUG ((LM_DEBUG,"%s: %d out of %d modules required\n",
name_.c_str(), num_extrefs_, num_modules_));
- makefile_->write_prolog(path_);
+ mpcfile_->write_prolog(path_);
for (int i = 0; i < num_modules_ ; i++)
if (modules_[i]->extref()) {
@@ -358,7 +332,7 @@ Library::write_export_list (int show_ref_counts)
n_sig = modules_[i]->imports().next())
countfile << n_sig->name() << endl;
}
- makefile_->write_file(modules_[i]->name().substring(0,modules_[i]->name().length()-2));
+ mpcfile_->write_file(modules_[i]->name().substring(0,modules_[i]->name().length()-2));
} else {
// const char * modname = modules_[i]->name().c_str();
exclusions
@@ -366,5 +340,5 @@ Library::write_export_list (int show_ref_counts)
<< endl;
}
- makefile_->write_epilog();
+ mpcfile_->write_epilog();
}
diff --git a/apps/soreduce/README b/apps/soreduce/README
index 8b4a5570419..5e0264bdab2 100644
--- a/apps/soreduce/README
+++ b/apps/soreduce/README
@@ -38,9 +38,9 @@ the following steps to generate its results.
process is repeated until the entire list of undefined symbols is
traversed without change.
-4. Makefiles are generated. Rather than invoking the linker directly, a make
+4. MPC files are generated. Rather than invoking the linker directly, an mpc
file is generated that may be used to build the libs. With these
- makefiles, the actual library will be named lib(orig)_subset.so.
+ mpc files, the actual library will be named (orig)_subset.
Analysis Artifacts
------------------
@@ -77,9 +77,8 @@ pass 4, undef count = 245
pass 5, undef count = 235
Writing results
Making directory /opt/wustl/ACE_wrappers/build/native/ace/usage_metrics
-mkdir: File exists
ACE: 61 out of 210 modules required
-writing file /opt/wustl/ACE_wrappers/build/native/ace/Makefile.ACE_subset
+writing file /opt/wustl/ACE_wrappers/build/native/ace/ACE_subset.mpc
Done.
The size of libACE.so before rebuilding:
@@ -101,7 +100,7 @@ Here is another example, using the Naming Service, and its simple test
client. Note that the orbsvcs results are bogus, the libraries are
already fairly well factored so that the additional subsetting by
soreduce is not effective. Also, due to the layout of the orbsvcs
-library source directory, the tool does not generate valid makefiles.
+library source directory, the tool may not generate valid mpc files.
bash$ $ACE_ROOT/apps/soreduce/soreduce Naming_Service/Naming_Service tests/Simple_Naming/client
discovering libraries
@@ -124,25 +123,22 @@ pass 6, undef count = 242
Writing results
Making directory /opt/wustl/ACE_wrappers/build/native/TAO/orbsvcs/orbsvcs/usage_metrics
TAO_CosNaming: 11 out of 256 modules required
-writing file /opt/wustl/ACE_wrappers/build/native/TAO/orbsvcs/orbsvcs/Makefile.TAO_CosNaming_subset
+writing file /opt/wustl/ACE_wrappers/build/native/TAO/orbsvcs/orbsvcs/TAO_CosNaming_subset.mpc
Making directory /opt/wustl/ACE_wrappers/build/native/TAO/orbsvcs/orbsvcs/usage_metrics
-mkdir: File exists
TAO_Svc_Utils: 8 out of 256 modules required
-writing file /opt/wustl/ACE_wrappers/build/native/TAO/orbsvcs/orbsvcs/Makefile.TAO_Svc_Utils_subset
+writing file /opt/wustl/ACE_wrappers/build/native/TAO/orbsvcs/orbsvcs/TAO_Svc_Utils_subset.mpc
Making directory /opt/wustl/ACE_wrappers/build/native/TAO/tao/IORTable/usage_metrics
TAO_IORTable: 4 out of 4 modules required
-writing file /opt/wustl/ACE_wrappers/build/native/TAO/tao/IORTable/Makefile.TAO_IORTable_subset
+writing file /opt/wustl/ACE_wrappers/build/native/TAO/tao/IORTable/TAO_IORTable_subset.mpc
Making directory /opt/wustl/ACE_wrappers/build/native/TAO/tao/PortableServer/usage_metrics
TAO_PortableServer: 26 out of 29 modules required
-writing file /opt/wustl/ACE_wrappers/build/native/TAO/tao/PortableServer/Makefile.TAO_PortableServer_subset
+writing file /opt/wustl/ACE_wrappers/build/native/TAO/tao/PortableServer/TAO_PortableServer_subset.mpc
Making directory /opt/wustl/ACE_wrappers/build/native/TAO/tao/usage_metrics
-mkdir: File exists
TAO: 160 out of 191 modules required
-writing file /opt/wustl/ACE_wrappers/build/native/TAO/tao/Makefile.TAO_subset
+writing file /opt/wustl/ACE_wrappers/build/native/TAO/tao/TAO_subset.mpc
Making directory /opt/wustl/ACE_wrappers/build/native/ace/usage_metrics
-mkdir: File exists
ACE: 75 out of 210 modules required
-writing file /opt/wustl/ACE_wrappers/build/native/ace/Makefile.ACE_subset
+writing file /opt/wustl/ACE_wrappers/build/native/ace/ACE_subset.mpc
Done.
Size before & after:
diff --git a/apps/soreduce/Library.h b/apps/soreduce/Library.h
index 081dd1864bf..9b291f80529 100644
--- a/apps/soreduce/Library.h
+++ b/apps/soreduce/Library.h
@@ -13,69 +13,68 @@
// library. It is used to manipulate the list of unresolved references by
// removing those that are resolved and adding those brought in by new modules
// that are required to resolve references. The Library is responsible
// for outputting a specialized makefile build the reduce footprint library.
#include "Obj_Module.h"
// FUZZ: disable check_for_streams_include
#include "ace/streams.h"
// The Makefile generator class serves as the base class used to output the
// custom makefiles (or in the future, project files) used to build the
// subsetted libraries.
// The base class will make libACE_subset.so
-class Makefile_Generator
+class MPC_Generator
{
public:
- Makefile_Generator (const ACE_CString& );
- virtual ~Makefile_Generator();
+ MPC_Generator (const ACE_CString& libname);
+ virtual ~MPC_Generator();
void write_prolog (const ACE_CString& );
void write_file (const ACE_CString& );
void write_epilog ();
protected:
- virtual void write_libdeps();
- virtual void write_initial_rules();
- virtual void write_final_rules();
+ virtual void write_baseprojects();
+ virtual void write_projectinfo();
- ofstream makefile_;
+ ofstream mpcfile_;
ACE_CString libname_;
- ACE_CString makefilename_;
+ ACE_CString mpcfilename_;
};
-// Generate makefiles for libraries dependant on ACE, that are not TAO.
-class Make_ACE_Dep_Lib : public Makefile_Generator
+// Generate mpc files for libraries dependant on ACE, that are not TAO.
+class MPC_ACE_Dep_Lib : public MPC_Generator
{
public:
- Make_ACE_Dep_Lib (const ACE_CString& );
+ MPC_ACE_Dep_Lib (const ACE_CString& libname);
protected:
- virtual void write_libdeps();
+ virtual void write_baseprojects();
+ virtual void write_projectinfo();
};
-// Generates makefiles for libTAO_subset.so
-class Make_TAO_Lib : public Make_ACE_Dep_Lib
+// Generates mpc files for libTAO_subset.so
+class MPC_TAO_Lib : public MPC_ACE_Dep_Lib
{
public:
- Make_TAO_Lib (const ACE_CString& );
+ MPC_TAO_Lib (const ACE_CString& libname);
protected:
- virtual void write_libdeps();
- virtual void write_initial_rules();
- virtual void write_final_rules();
+ virtual void write_baseprojects();
+ virtual void write_projectinfo();
};
// Generates makefiles for libs dependant on TAO. This has a problem when
// building libraries in the orbsvcs tree.
-class Make_TAO_Dep_Lib : public Make_TAO_Lib
+class MPC_TAO_Dep_Lib : public MPC_TAO_Lib
{
public:
- Make_TAO_Dep_Lib (const ACE_CString& );
+ MPC_TAO_Dep_Lib (const ACE_CString& );
protected:
- virtual void write_libdeps();
+ virtual void write_baseprojects();
+ virtual void write_projectinfo();
};
//----------------------------------------------------------------------------
@@ -84,7 +83,7 @@ class Library
{
public:
- Library (const char *name = 0 );
+ Library (const ACE_TCHAR *name = 0 );
/// Constructor is responsible for loading all of the modules related to the
/// library
~Library ();
@@ -96,13 +95,13 @@ public:
// as exported, and its unresolved symbols are added to the undef list.
void resolve (Sig_List &undefs);
// Outputs a list of files suitable for inclusion in a makefile to produce
// a subsetted library. If the argument is non-zero, reference countes for
// each module are also listed.
void write_export_list ( int );
// set the path to find the .so files
- void set_path (const char *p );
+ void set_path (const ACE_TCHAR *p );
// Load the actual .so files from the path.
void load_modules();
@@ -123,7 +122,7 @@ private:
Obj_Module **modules_;
Sig_List exported_;
- Makefile_Generator *makefile_;
+ MPC_Generator *mpcfile_;
};
#endif /* _LIBRARY_H_ */
@@ -13,69 +13,68 @@
// removing those that are resolved and adding those brought in by new modules
// that are required to resolve references. The Library is responsible
-// for outputting a specialized makefile build the reduce footprint library.
+// for outputting a specialized mpc file to build the reduce footprint library.
#include "Obj_Module.h"
// FUZZ: disable check_for_streams_include
@@ -13,69 +13,68 @@
// FUZZ: disable check_for_streams_include
#include "ace/streams.h"
-// The Makefile generator class serves as the base class used to output the
-// custom makefiles (or in the future, project files) used to build the
-// subsetted libraries.
+// The MPC generator class serves as the base class used to output the
+// custom mpc files used to build the subsetted libraries.
// The base class will make libACE_subset.so
@@ -96,13 +95,13 @@ public:
// as exported, and its unresolved symbols are added to the undef list.
void resolve (Sig_List &undefs);
- // Outputs a list of files suitable for inclusion in a makefile to produce
+ // Outputs a list of files suitable for inclusion in an mpc file to produce
// a subsetted library. If the argument is non-zero, reference countes for
// each module are also listed.